package com.tencent.ugcupload.demo;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.tencent.ugcupload.demo.videoupload.TXUGCPublish;
import com.tencent.ugcupload.demo.videoupload.TXUGCPublishTypeDef;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;

import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.Request;
import okhttp3.Response;

public class MainActivity extends Activity implements View.OnClickListener, TXUGCPublishTypeDef.ITXVideoPublishListener {

    private static final String TAG = MainActivity.class.getName();
    public static final int REQUESTCODE = 1;
    private static final int REQUEST_EXTERNAL_STORAGE = 1;
    private static String[] PERMISSIONS_STORAGE = {
            "android.permission.READ_EXTERNAL_STORAGE",
            "android.permission.WRITE_EXTERNAL_STORAGE"};
    private TextView mResultMsg;
    private ProgressBar mProgress;
    private String mVideoPath;
    private TXUGCPublish mVideoPublish = null;
    // signature计算规则可参考 https://www.qcloud.com/document/product/266/9221
    private String mSignature = "";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        if ((getIntent().getFlags() & Intent.FLAG_ACTIVITY_BROUGHT_TO_FRONT) != 0) {
            Log.d(TAG, "brought to front");
            finish();
            return;
        }

        setContentView(R.layout.activity_main);
        mResultMsg = (TextView) findViewById(R.id.resultMsg);
        mProgress = (ProgressBar) findViewById(R.id.progressBar);
    }


    public boolean verifyStoragePermissions() {
        try {
            //检测是否有写的权限
            int permission = ActivityCompat.checkSelfPermission(this,
                    "android.permission.WRITE_EXTERNAL_STORAGE");
            if (permission != PackageManager.PERMISSION_GRANTED) {
                // 没有写的权限，去申请写的权限，会弹出对话框
                ActivityCompat.requestPermissions(this, PERMISSIONS_STORAGE, REQUEST_EXTERNAL_STORAGE);
                return false;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return true;
    }

    @Override
    public void onClick(View view) {
        if (TextUtils.isEmpty(mSignature)) {
            // signature计算规则可参考 https://www.qcloud.com/document/product/266/9221
            Toast.makeText(view.getContext(), "请填写签名(mSignature is null.)", Toast.LENGTH_SHORT).show();
            return;
        }
        switch (view.getId()) {
            case R.id.choose_file:
                if (verifyStoragePermissions());
                    chooseFile();
                break;
            case R.id.upload:
                beginUpload();
                break;
            case R.id.resume:
                resumeUpload();
                break;
            case R.id.pause:
                pauseUpload();
                break;
            default:
                break;
        }
    }

    private void pauseUpload() {
        if (mVideoPublish != null) {
            mVideoPublish.canclePublish();
        }
    }

    private void resumeUpload() {
        if (mVideoPublish != null) {
            TXUGCPublishTypeDef.TXPublishParam param = new TXUGCPublishTypeDef.TXPublishParam();
            // signature计算规则可参考 https://www.qcloud.com/document/product/266/9221
            param.signature = mSignature;
            param.videoPath = mVideoPath;
            int publishCode = mVideoPublish.publishVideo(param);
            if (publishCode != 0) {
                mResultMsg.setText("发布失败，错误码：" + publishCode);
            }
        }
    }

    private void beginUpload() {
        mResultMsg.setText("");
        mProgress.setProgress(0);
        if (mVideoPublish == null) {
            mVideoPublish = new TXUGCPublish(this.getApplicationContext(), "independence_android");
            // mVideoPublish.setAppId(123456);
            mVideoPublish.setListener(this);
        }

        TXUGCPublishTypeDef.TXPublishParam param = new TXUGCPublishTypeDef.TXPublishParam();
        param.signature = mSignature;
        param.videoPath = mVideoPath;
        int publishCode = mVideoPublish.publishVideo(param);
        if (publishCode != 0) {
            mResultMsg.setText("发布失败，错误码：" + publishCode);
        }

    }

    private void chooseFile() {
        Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
        intent.setType("video/*");//设置类型，我这里是任意类型，任意后缀的可以这样写。
        intent.addCategory(Intent.CATEGORY_OPENABLE);
        Intent wrapIntent = Intent.createChooser(intent, null);
        startActivityForResult(wrapIntent, REQUESTCODE);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == REQUESTCODE) {
            if (resultCode == RESULT_OK) {
                Uri uri = data.getData();
                Log.d(TAG, "File Uri: " + uri.toString());
                // Get the path
                String path = null;
                path = FileUtils.getRealPathFromUri(this, uri);
                mVideoPath = path;
                Log.d(TAG, "File Path: " + path);
            }
        }
    }

    @Override
    public void onPublishProgress(long uploadBytes, long totalBytes) {
        mProgress.setProgress((int) (100 * uploadBytes / totalBytes));
    }

    @Override
    public void onPublishComplete(TXUGCPublishTypeDef.TXPublishResult result) {
        mResultMsg.setText(result.retCode + " Msg:" + (result.retCode == 0 ? result.videoURL : result.descMsg));
    }



}
